==> config-0.5.0-sources.jar: org/opennms/integration/api/xml/JaxbUtils.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.integration.api.xml;

import java.io.StringReader;
import java.io.StringWriter;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;

class JaxbUtils {

    public static String toXml(Object o, Class<?> clazz) {
        try {
            final StringWriter sw = new StringWriter();
            final JAXBContext context = JAXBContext.newInstance(clazz);
            final Marshaller m = context.createMarshaller();
            m.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            m.marshal(o, sw);
            return sw.toString();
        } catch(Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    public static <V> V fromXml(String xml, Class<V> clazz) {
        try (StringReader reader = new StringReader(xml)){
            final JAXBContext context = JAXBContext.newInstance(clazz);
            final Unmarshaller um = context.createUnmarshaller();
            return (V)um.unmarshal(reader);
        } catch(Exception ex) {
            throw new RuntimeException(ex);
        }
    }
}

==> config-1.3.0-sources.jar: org/opennms/integration/api/xml/JaxbUtils.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.integration.api.xml;

import java.io.InputStream;
import java.io.StringReader;
import java.io.StringWriter;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;

class JaxbUtils {

    public static String toXml(Object o, Class<?> clazz) {
        try {
            final StringWriter sw = new StringWriter();
            final JAXBContext context = JAXBContext.newInstance(clazz);
            final Marshaller m = context.createMarshaller();
            m.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            m.marshal(o, sw);
            return sw.toString();
        } catch(Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    public static <V> V fromXml(String xml, Class<V> clazz) {
        try (StringReader reader = new StringReader(xml)){
            final JAXBContext context = JAXBContext.newInstance(clazz);
            final Unmarshaller um = context.createUnmarshaller();
            return (V)um.unmarshal(reader);
        } catch(Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    public static <V> V fromXml(InputStream xml, Class<V> clazz) {
        try {
            final JAXBContext context = JAXBContext.newInstance(clazz);
            final Unmarshaller um = context.createUnmarshaller();
            return (V) um.unmarshal(xml);
        } catch (JAXBException ex) {
            throw new RuntimeException(ex);
        }
    }
}
